Scheduler

Trait Scheduler 

pub trait Scheduler {
    // Required methods
    fn is_ready(&self) -> bool;
    fn time_till_next_job(&self) -> Option<Duration>;
    fn tick(&mut self);
}
An interface for scheduling sync jobs.

Required Methods

fn is_ready(&self) -> bool

Returns true if the scheduler is ready to run.

fn time_till_next_job(&self) -> Option<Duration>

Returns the duration till the next job is supposed to run.

fn tick(&mut self)

Increments time for the scheduler and executes any pending jobs.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors